@@ -9,8 +9,8 @@ from compas_fab.robots import AttachedCollisionMesh
 from compas_fab.robots.time_ import Duration
 
 __all__ = [
-    'JointTrajectoryPoint',
     'JointTrajectory',
+    'JointTrajectoryPoint',
     'Trajectory',
 ]
 
@@ -144,8 +144,8 @@ class JointTrajectoryPoint(Configuration):
 
     @data.setter
     def data(self, data):
-        self._joint_values = FixedLengthList(data.get('joint_values') or [])
-        self._joint_types = FixedLengthList(data.get('joint_types') or [])
+        self._joint_values = FixedLengthList(data.get('joint_values') or data.get('values') or [])
+        self._joint_types = FixedLengthList(data.get('joint_types') or data.get('types') or [])
         self._joint_names = FixedLengthList(data.get('joint_names') or [])
         self._velocities = FixedLengthList(data.get('velocities') or [])
         self._accelerations = FixedLengthList(data.get('accelerations') or [])
@@ -334,7 +334,7 @@ class JointTrajectory(Trajectory):
         if data.get('start_configuration'):
             self.start_configuration = Configuration.from_data(data.get('start_configuration'))
         self.fraction = data.get('fraction')
-        self.attached_collision_meshes = [AttachedCollisionMesh.from_data(acm_data) for acm_data in data.get('attached_collision_meshes')]
+        self.attached_collision_meshes = [AttachedCollisionMesh.from_data(acm_data) for acm_data in data.get('attached_collision_meshes', [])]
 
     @property
     def time_from_start(self):
